# Changelog

## 0.1: Initial release of the package.

  - Support for free functions as tasks
  - Ability to run tasks in subprocesses
  - Ability to execute tasks with different python interpreters
  - Simple file system cache for caching task results
